# Meta-analysis on the ecological effects of alien macrophytes - Sam Tasker, Dave Bilton, Andy Foggo

require(esc)
require(metafor)
require(dmetar)

# Importing raw data
data <- read.csv("~/Crassula PhD/Meta-analysis/finaldata.csv")

### Calculating effect sizes (Hedge's g)
effectsizes<- esc_mean_se(
  data$mal, 
  data$seal, 
  data$nal,
  data$mco, 
  data$seco, 
  data$nco,
  es.type=c('g'),
  study=data$title)

## Exporting the above results, before combining manually with the original dataset in excel
write.csv(effectsizes,"~/Crassula PhD/Meta-analysis/effectsizes.csv", row.names = FALSE)

rm(effectsizes)
rm(data)

### Importing resulting CSV
alldata <- read.csv("~/Crassula PhD/Meta-analysis/alldata0408.csv")

alldata$habit <- as.factor(alldata$habit)
alldata$climate <- as.factor(alldata$climate)
alldata$var <- as.factor(alldata$var)
alldata$metric <- as.factor(alldata$metric)
alldata$functionalgroup <- as.factor(alldata$functionalgroup)
alldata$controltype <- as.factor(alldata$controltype)
alldata$habitat <- as.factor(alldata$habitat)
alldata$studytype <- as.factor(alldata$studytype)

splitgroups <- (split(alldata, alldata$var))
allabundance <- splitgroups$Abundance
alldiversity <- splitgroups$Diversity
rm(splitgroups)

splitgroups <- (split(alldata, alldata$functionalgroup))
allplants <- splitgroups$Macrophytes
allinverts <- splitgroups$Macroinvertebrates
allfish <- splitgroups$Fish
rm(splitgroups)

splitgroups <- (split(allplants, allplants$var))
plantabundance <- splitgroups$Abundance
plantdiversity <- splitgroups$Diversity

splitgroups <- (split(allinverts, allinverts$var))
invertabundance <- splitgroups$Abundance
invertdiversity <- splitgroups$Diversity

splitgroups <- (split(allfish, allfish$var))
fishabundance <- splitgroups$Abundance
fishdiversity <- splitgroups$Diversity

splitgroups <- (split(allplants, allplants$habit))
plantsubmerged <- splitgroups$Submerged
plantfloating <- splitgroups$Floating
plantemergent <- splitgroups$Emergent

splitgroups <- (split(allinverts, allinverts$habit))
invertsubmerged <- splitgroups$Submerged
invertfloating <- splitgroups$Floating
invertemergent <- splitgroups$Emergent

splitgroups <- (split(invertsubmerged, invertsubmerged$controltype))
isnative <- splitgroups$'Native vegetation'
isbare <- splitgroups$'No vegetation'

splitgroups <- (split(allfish, allfish$habit))
fishsubmerged <- splitgroups$Submerged
fishfloating <- splitgroups$Floating
fishemergent <- splitgroups$Emergent

splitgroups <- (split(alldata, alldata$bin))
typha <- splitgroups$'Typha spp.'
myrio <- splitgroups$'Myriophyllum spicatum'
hydrilla <- splitgroups$'Hydrilla verticillata'
phragmites <- splitgroups$'Phragmites australis'
othersub <- splitgroups$'Other submerged'

splitgroups <- (split(typha, typha$functionalgroup))
typlants <- splitgroups$Macrophytes
tyinverts <- splitgroups$Macroinvertebrates
tyfish <- splitgroups$Fish

splitgroups <- (split(myrio, myrio$functionalgroup))
myplants <- splitgroups$Macrophytes
myinverts <- splitgroups$Macroinvertebrates
myfish <- splitgroups$Fish

splitgroups <- (split(hydrilla, hydrilla$functionalgroup))
hyplants <- splitgroups$Macrophytes
hyinverts <- splitgroups$Macroinvertebrates
hyfish <- splitgroups$Fish

splitgroups <- (split(phragmites, phragmites$functionalgroup))
phplants <- splitgroups$Macrophytes
phinverts <- splitgroups$Macroinvertebrates
phfish <- splitgroups$Fish

splitgroups <- (split(othersub, othersub$functionalgroup))
otsuplants <- splitgroups$Macrophytes
otsuinverts <- splitgroups$Macroinvertebrates
otsufish <- splitgroups$Fish

rm(splitgroups)

# Using ANOVA to test whether metrics can be lumped together

aovabundance <- aov(allabundance$effectsize~allabundance$metric)
summary(aovabundance)
aovdiversity <- aov(alldiversity$effectsize~alldiversity$metric)
summary(aovdiversity)
aovplantabundance <- aov(plantabundance$effectsize~plantabundance$metric)
summary(aovplantabundance)
aovplantdiversity <- aov(plantdiversity$effectsize~plantdiversity$metric)
summary(aovplantdiversity)
aovinvertabundance <- aov(invertabundance$effectsize~invertabundance$metric)
summary(aovinvertabundance)
aovinvertdiversity <- aov(invertdiversity$effectsize~invertdiversity$metric)
summary(aovinvertdiversity)
aovfishabundance <- aov(fishabundance$effectsize~fishabundance$metric)
summary(aovfishabundance)
aovfishdiversity <- aov(fishdiversity$effectsize~fishdiversity$metric)
summary(aovfishdiversity)

# Full vs. reduced models
# 3 full model iterations ('control-type-nested-within-study-type','habitat', 'climate' mods) not shown for brevity

allabundance$aliensp <- as.factor(allabundance$aliensp)
alldiversity$aliensp <- as.factor(alldiversity$aliensp)
plantabundance$aliensp <- as.factor(plantabundance$aliensp)
plantdiversity$aliensp <- as.factor(plantdiversity$aliensp)
invertabundance$aliensp <- as.factor(invertabundance$aliensp)
invertdiversity$aliensp <- as.factor(invertdiversity$aliensp)
fishabundance$aliensp <- as.factor(fishabundance$aliensp)
fishdiversity$aliensp <- as.factor(fishdiversity$aliensp)

alla1.mods <- rma.mv(effectsize, variance,
                       random = list(~ 1 | title/case), 
                       data = allabundance,
                       method = "ML",
                       slab = (author))
summary(alla1.mods)

alla2.mods<- rma.mv(effectsize, variance,
                      random = list(~ 1 | title/case),
                      data = allabundance,
                      method = "ML",
                      mod = aliensp,
                      slab = (author))
summary(alla2.mods)

anova(alla1.mods, alla2.mods)

alld1.mods <- rma.mv(effectsize, variance,
                     random = list(~ 1 | title/case), 
                     data = alldiversity,
                     method = "ML",
                     slab = (author))
summary(alld1.mods)

alld2.mods<- rma.mv(effectsize, variance,
                    random = list(~ 1 | title/case),
                    data = alldiversity,
                    method = "ML",
                    mod = aliensp,
                    slab = (author))
summary(alld2.mods)

anova(alld1.mods, alld2.mods)

planta1.mods <- rma.mv(effectsize, variance,
                       random = list(~ 1 | title/case), 
                       data = plantabundance,
                       method = "ML",
                       slab = (author))
summary(planta1.mods)

planta2.mods<- rma.mv(effectsize, variance,
                      random = list(~ 1 | title/case),
                      data = plantabundance,
                      method = "ML",
                      mod = aliensp,
                      slab = (author))
summary(planta2.mods)

anova(planta1.mods, planta2.mods)

plantd1.mods<- rma.mv(effectsize, variance,
                      random = list(~ 1 | title/case),
                      data = plantdiversity,
                      method = "ML",
                      slab = (author))
summary(plantd1.mods)

plantd2.mods<- rma.mv(effectsize, variance,
                      random = list(~ 1 | title/case),
                      data = plantdiversity,
                      method = "ML",
                      mod = aliensp,
                      slab = (author))
summary(plantd2.mods)

anova(plantd1.mods, plantd2.mods)

inverta1.mods<- rma.mv(effectsize, variance,
                       random = list(~ 1 | title/case),
                       data = invertabundance,
                       method = "ML",
                       slab = (author))
summary(inverta1.mods)

inverta2.mods<- rma.mv(effectsize, variance,
                       random = list(~ 1 | title/case),
                       data = invertabundance,
                       method = "ML",
                       mod = aliensp,
                       slab = (author))
summary(inverta2.mods)

anova(inverta1.mods, inverta2.mods)

invertd1.mods<- rma.mv(effectsize, variance,
                       random = list(~ 1 | title/case),
                       data = invertdiversity,
                       method = "ML",
                       slab = (author))
summary(invertd1.mods)

invertd2.mods<- rma.mv(effectsize, variance,
                       random = list(~ 1 | title/case),
                       data = invertdiversity,
                       method = "ML",
                       mod = aliensp,
                       slab = (author))
summary(invertd2.mods)

anova(invertd1.mods, invertd2.mods)

fisha1.mods<- rma.mv(effectsize, variance,
                     random = list(~ 1 | title/case),
                     data = fishabundance,
                     method = "ML",
                     slab = (author))
summary(fisha1.mods)

fisha2.mods<- rma.mv(effectsize, variance,
                     random = list(~ 1 | title/case),
                     data = fishabundance,
                     method = "ML",
                     mod = aliensp,
                     slab = (author))
summary(fisha2.mods)

anova(fisha1.mods, fisha2.mods)

fishd1.mods<- rma.mv(effectsize, variance,
                     random = list(~ 1 | title/case),
                     data = fishdiversity,
                     method = "ML",
                     slab = (author))
summary(fishd1.mods)

fishd2.mods<- rma.mv(effectsize, variance,
                     random = list(~ 1 | title/case),
                     data = fishdiversity,
                     method = "ML",
                     mod = aliensp,
                     slab = (author))
summary(fishd2.mods)

anova(fishd1.mods, fishd2.mods)

# Multilevel random effects models - grand means

allabundance.mods <- rma.mv(effectsize, variance,
                            random = list(~ 1 | title/case),
                            data = allabundance,
                            method = "REML",
                            slab = (author))
summary(allabundance.mods)

alldiversity.mods <- rma.mv(effectsize, variance,
                            random = list(~ 1 | title/case),
                            data = alldiversity,
                            method = "REML",
                            slab = (author))
summary(alldiversity.mods)

# Multilevel random effects models - focal taxa

planta.mods <- rma.mv(effectsize, variance,
                      random = list(~ 1 | title/case), 
                      data = plantabundance,
                      method = "REML",
                      slab = (author))
summary(planta.mods)

plantd.mods<- rma.mv(effectsize, variance,
                     random = list(~ 1 | title/case),
                     data = plantdiversity,
                     method = "REML",
                     slab = (author))
summary(plantd.mods)

inverta.mods<- rma.mv(effectsize, variance,
                      random = list(~ 1 | title/case),
                      data = invertabundance,
                      method = "REML",
                      slab = (author))
summary(inverta.mods)

invertd.mods<- rma.mv(effectsize, variance,
                      random = list(~ 1 | title/case),
                      data = invertdiversity,
                      method = "REML",
                      slab = (author))
summary(invertd.mods)

fisha.mods<- rma.mv(effectsize, variance,
                    random = list(~ 1 | title/case),
                    data = fishabundance,
                    method = "REML",
                    slab = (author))
summary(fisha.mods)

fishd.mods<- rma.mv(effectsize, variance,
                    random = list(~ 1 | title/case),
                    data = fishdiversity,
                    method = "REML",
                    slab = (author))
summary(fishd.mods)

# Multilevel random effects models - growth form

plantsub.mods <- rma.mv(effectsize, variance,
                        random = list(~ 1 | title/case),
                        data = plantsubmerged,
                        method = "REML",
                        slab = (author))
summary(plantsub.mods)

plantfloat.mods <- rma.mv(effectsize, variance,
                          random = list(~ 1 | title/case),
                          data = plantfloating,
                          method = "REML",
                          slab = (author))
summary(plantfloat.mods) # k insufficient

plantem.mods <- rma.mv(effectsize, variance,
                       random = list(~ 1 | title/case),
                       data = plantemergent,
                       method = "REML",
                       slab = (author))
summary(plantem.mods)

invertsub.mods <- rma.mv(effectsize, variance,
                         random = list(~ 1 | title/case),
                         data = invertsubmerged,
                         method = "REML",
                         slab = (author))
summary(invertsub.mods)

    # Further inverts: submerged alien analysis
    # Split native vegetation controls from unvegetated control cases

isnative.mods <- rma.mv(effectsize, variance,
                        random = list(~ 1 | title/case),
                        data = isnative,
                        method = "REML",
                        slab = (author))
summary(isnative.mods)

isbare.mods <- rma.mv(effectsize, variance,
                      random = list(~ 1 | title/case),
                      data = isbare,
                      method = "REML",
                      slab = (author))
summary(isbare.mods)

invertfloat.mods <- rma.mv(effectsize, variance,
                           random = list(~ 1 | title/case),
                           data = invertfloating,
                           method = "REML",
                           slab = (author))
summary(invertfloat.mods)

invertem.mods <- rma.mv(effectsize, variance,
                        random = list(~ 1 | title/case),
                        data = invertemergent,
                        method = "REML",
                        slab = (author))
summary(invertem.mods)

fishsub.mods <- rma.mv(effectsize, variance,
                       random = list(~ 1 | title/case),
                       data = fishsubmerged,
                       method = "REML",
                       slab = (author))
summary(fishsub.mods)

fishfloat.mods <- rma.mv(effectsize, variance,
                         random = list(~ 1 | title/case),
                         data = fishfloating,
                         method = "REML",
                         slab = (author))
summary(fishfloat.mods) # k insufficient

fishem.mods <- rma.mv(effectsize, variance,
                      random = list(~ 1 | title/case),
                      data = fishemergent,
                      method = "REML",
                      slab = (author))
summary(fishem.mods) # k insufficient

# Multilevel random effects models - key aliens

typlants.mods <- rma.mv(effectsize, variance,
                        random = list(~ 1 | title/case),
                        data = typlants,
                        method = "REML",
                        slab = (author))
summary(typlants.mods)

tyinverts.mods <- rma.mv(effectsize, variance,
                         random = list(~ 1 | title/case),
                         data = tyinverts,
                         method = "REML",
                         slab = (author))
summary(tyinverts.mods) # k insufficient

tyfish.mods <- rma.mv(effectsize, variance,
                      random = list(~ 1 | title/case),
                      data = tyfish,
                      method = "REML",
                      slab = (author))
summary(tyfish.mods) # k insufficient

myplants.mods <- rma.mv(effectsize, variance,
                        random = list(~ 1 | title/case),
                        data = myplants,
                        method = "REML",
                        slab = (author))
summary(myplants.mods) # k insufficient

myinverts.mods <- rma.mv(effectsize, variance,
                         random = list(~ 1 | title/case),
                         data = myinverts,
                         method = "REML",
                         slab = (author))
summary(myinverts.mods)

myfish.mods <- rma.mv(effectsize, variance,
                      random = list(~ 1 | title/case),
                      data = myfish,
                      method = "REML",
                      slab = (author))
summary(myfish.mods) # k insufficient

hyplants.mods <- rma.mv(effectsize, variance,
                        random = list(~ 1 | title/case),
                        data = hyplants,
                        method = "REML",
                        slab = (author))
summary(hyplants.mods)  # k insufficient

hyinverts.mods <- rma.mv(effectsize, variance,
                         random = list(~ 1 | title/case),
                         data = hyinverts,
                         method = "REML",
                         slab = (author))
summary(hyinverts.mods)

hyfish.mods <- rma.mv(effectsize, variance,
                      random = list(~ 1 | title/case),
                      data = hyfish,
                      method = "REML",
                      slab = (author))
summary(hyfish.mods)

phplants.mods <- rma.mv(effectsize, variance,
                        random = list(~ 1 | title/case),
                        data = phplants,
                        method = "REML",
                        slab = (author))
summary(phplants.mods) # sig neg!

phinverts.mods <- rma.mv(effectsize, variance,
                         random = list(~ 1 | title/case),
                         data = phinverts,
                         method = "REML",
                         slab = (author))
summary(phinverts.mods) # k insufficient

phfish.mods <- rma.mv(effectsize, variance,
                      random = list(~ 1 | title/case),
                      data = phfish,
                      method = "REML",
                      slab = (author))
summary(phfish.mods) # k insufficient

otsuplants.mods <- rma.mv(effectsize, variance,
                        random = list(~ 1 | title/case),
                        data = otsuplants,
                        method = "REML",
                        slab = (author))
summary(otsuplants.mods) # k insufficient

otsuinverts.mods <- rma.mv(effectsize, variance,
                         random = list(~ 1 | title/case),
                         data = otsuinverts,
                         method = "REML",
                         slab = (author))
summary(otsuinverts.mods) # non-sig - pos sub effects driven by hydrilla and myrio!

otsufish.mods <- rma.mv(effectsize, variance,
                      random = list(~ 1 | title/case),
                      data = otsufish,
                      method = "REML",
                      slab = (author))
summary(otsufish.mods) # k insufficient

# Influence analyses

dfbetas.rma.mv(allabundance.mods)

dfbetas.rma.mv(alldiversity.mods)

dfbetas.rma.mv(planta.mods)

dfbetas.rma.mv(plantd.mods)

dfbetas.rma.mv(inverta.mods)

dfbetas.rma.mv(invertd.mods)

dfbetas.rma.mv(fisha.mods)

dfbetas.rma.mv(fishd.mods)

  # Following influence analyses only cover those subgroups which met the 'k =' criteria for subgroup analysis

dfbetas.rma.mv(plantsub.mods)

dfbetas.rma.mv(plantem.mods)

dfbetas.rma.mv(invertsub.mods)

dfbetas.rma.mv(invertfloat.mods)

dfbetas.rma.mv(invertem.mods)

dfbetas.rma.mv(fishsub.mods)

dfbetas.rma.mv(typlants.mods)

dfbetas.rma.mv(myinverts.mods)

dfbetas.rma.mv(hyinverts.mods)

dfbetas.rma.mv(hyfish.mods)

dfbetas.rma.mv(phplants.mods)

dfbetas.rma.mv(otsuinverts.mods)

      # Sensitivity analysis - influential case(s) removed in excel 

      fishabundinf <- read.csv("~/Crassula PhD/Meta-analysis/fishainfluence.csv") # Houston 2002 removed

      fishainf.mods<- rma.mv(effectsize, variance,
                       random = list(~ 1 | title/case),
                       data = fishabundinf,
                       method = "REML",
                       slab = (author))
      summary(fishainf.mods)

      invertdiversinf <- read.csv("~/Crassula PhD/Meta-analysis/invertdinfluence.csv") # Ceschin 2020 removed

      invertdinf.mods<- rma.mv(effectsize, variance,
                         random = list(~ 1 | title/case),
                         data = invertdiversinf,
                         method = "REML",
                         slab = (author))
      summary(invertdinf.mods)
      
      hyinvinf <- read.csv("~/Crassula PhD/Meta-analysis/hydrillainfluence.csv")
      
      hyinvinf.mods <- rma.mv(effectsize, variance,
                              random = list(~ 1 | title/case),
                              data = hyinvinf,
                              method = "REML",
                              slab = (author))
      summary(hyinvinf.mods)

# Publication bias
      
aa.egger = rma.mv(effectsize, variance,
                        random = list(~ 1 | title/case),
                        data = allabundance,
                        method = "REML",
                        mod = sqrt(variance))
aa.egger

ad.egger = rma.mv(effectsize, variance,
                  random = list(~ 1 | title/case),
                  data = alldiversity,
                  method = "REML",
                  mod = sqrt(variance))
ad.egger

pa.egger = rma.mv(effectsize, variance,
                  random = list(~ 1 | title/case),
                  data = plantabundance,
                  method = "REML",
                  mod = sqrt(variance))
pa.egger

pd.egger = rma.mv(effectsize, variance,
                  random = list(~ 1 | title/case),
                  data = plantdiversity,
                  method = "REML",
                  mod = sqrt(variance))
pd.egger

ia.egger = rma.mv(effectsize, variance,
                  random = list(~ 1 | title/case),
                  data = invertabundance,
                  method = "REML",
                  mod = sqrt(variance))
ia.egger

id.egger = rma.mv(effectsize, variance,
                  random = list(~ 1 | title/case),
                  data = invertdiversity,
                  method = "REML",
                  mod = sqrt(variance))
id.egger

fa.egger = rma.mv(effectsize, variance,
                  random = list(~ 1 | title/case),
                  data = fishabundance,
                  method = "REML",
                  mod = sqrt(variance))
fa.egger

fd.egger = rma.mv(effectsize, variance,
                  random = list(~ 1 | title/case),
                  data = fishdiversity,
                  method = "REML",
                  mod = sqrt(variance))
fd.egger

  # Following publication bias analyses only cover those subgroups which met the 'k =' criteria for subgroup analysis

ps.egger = rma.mv(effectsize, variance,
                  random = list(~ 1 | title/case),
                  data = plantsubmerged,
                  method = "REML",
                  mod = sqrt(variance))
ps.egger

pe.egger = rma.mv(effectsize, variance,
                  random = list(~ 1 | title/case),
                  data = plantemergent,
                  method = "REML",
                  mod = sqrt(variance))
pe.egger

is.egger = rma.mv(effectsize, variance,
                  random = list(~ 1 | title/case),
                  data = invertsubmerged,
                  method = "REML",
                  mod = sqrt(variance))
is.egger

if.egger = rma.mv(effectsize, variance,
                  random = list(~ 1 | title/case),
                  data = invertfloating,
                  method = "REML",
                  mod = sqrt(variance))
if.egger

ie.egger = rma.mv(effectsize, variance,
                  random = list(~ 1 | title/case),
                  data = invertemergent,
                  method = "REML",
                  mod = sqrt(variance))
ie.egger

fs.egger = rma.mv(effectsize, variance,
                  random = list(~ 1 | title/case),
                  data = fishsubmerged,
                  method = "REML",
                  mod = sqrt(variance))
fs.egger

tp.egger = rma.mv(effectsize, variance,
                  random = list(~ 1 | title/case),
                  data = typlants,
                  method = "REML",
                  mod = sqrt(variance))
tp.egger

myi.egger = rma.mv(effectsize, variance,
                   random = list(~ 1 | title/case),
                   data = myinverts,
                   method = "REML",
                   mod = sqrt(variance))
myi.egger

hyi.egger = rma.mv(effectsize, variance,
                   random = list(~ 1 | title/case),
                   data = hyinverts,
                   method = "REML",
                   mod = sqrt(variance))
hyi.egger

hyf.egger = rma.mv(effectsize, variance,
                   random = list(~ 1 | title/case),
                   data = hyfish,
                   method = "REML",
                   mod = sqrt(variance))
hyf.egger

php.egger = rma.mv(effectsize, variance,
                   random = list(~ 1 | title/case),
                   data = phplants,
                   method = "REML",
                   mod = sqrt(variance))
php.egger

otsi.egger = rma.mv(effectsize, variance,
                   random = list(~ 1 | title/case),
                   data = otsuinverts,
                   method = "REML",
                   mod = sqrt(variance))
otsi.egger

# Heterogeneity statistics

mlm.variance.distribution(x = allabundance.mods)

mlm.variance.distribution(x = alldiversity.mods)

mlm.variance.distribution(x = planta.mods)

mlm.variance.distribution(x = plantd.mods)

mlm.variance.distribution(x = inverta.mods)

mlm.variance.distribution(x = invertd.mods)

mlm.variance.distribution(x = fisha.mods)

mlm.variance.distribution(x = fishd.mods)

  # Following heterogeneity analyses only cover those subgroups which met the 'k =' criteria for subgroup analysis

mlm.variance.distribution(x = plantsub.mods)

mlm.variance.distribution(x = plantem.mods)

mlm.variance.distribution(x = invertsub.mods)

mlm.variance.distribution(x = invertfloat.mods)

mlm.variance.distribution(x = invertem.mods)

mlm.variance.distribution(x = fishsub.mods)

mlm.variance.distribution(x = typlants.mods)

mlm.variance.distribution(x = myinverts.mods)

mlm.variance.distribution(x = hyinverts.mods)

mlm.variance.distribution(x = hyfish.mods)

mlm.variance.distribution(x = phplants.mods)

mlm.variance.distribution(x = otsuinverts.mods)

# Plotting

pooled <- read.csv("~/Crassula PhD/Meta-analysis/pooledmain.csv")

pooled$group <- factor(pooled$group, levels = c('Fish diversity', 'Fish abundance',
                                                'Macroinvertebrate diversity','Macroinvertebrate abundance',
                                                'Macrophyte diversity', 'Macrophyte abundance', 
                                                'Overall diversity', 'Overall abundance'))

library(ggplot2)
fp <- ggplot(data=pooled, aes(x=group, y=g, ymin=ci_l, ymax=ci_h, size = size)) +
  scale_size(range = 3:4) +
  geom_errorbar(size=1, width=.2, 
                aes(color = c('#00BA38', '#00BA38', '#F8766D', '#F8766D',  "#619CFF", "#619CFF", "black", 'black')), 
                show.legend = FALSE) +
  geom_point(data=pooled, shape = 21, color='black', aes(fill = col), 
             stroke =2.5, show.legend = FALSE) +
  geom_hline(yintercept=0, lty=2) +
  ylim(c(-3, 3)) +
  coord_flip() +
  xlab("") + ylab("") +
  theme_minimal()+
  theme(text=element_text(family="sans", color = , size=11, face = 'bold'))

fp + scale_fill_manual(values=c("gold", '#F8766D', '#00BA38', "#619CFF")) + 
  scale_color_manual(values=c("black", '#F8766D', '#00BA38', "#619CFF"))

####

pooled <- read.csv("~/Crassula PhD/Meta-analysis/pooledhabit.csv")

pooled$taxhab <- factor(pooled$taxhab, levels = c('emergent: inverts', 'emergent: plants',
                                                  'floating: inverts',
                                                  'submerged: fish', 'submerged: inverts', 'submerged: plants'))

library(ggplot2)
hfp <- ggplot(data=pooled, aes(x=taxhab, y=g, ymin=ci_l, ymax=ci_h)) +
  geom_hline(yintercept=0, lty=2) +
  geom_errorbar(size=1, width=.2, aes(color = habit), show.legend = FALSE) +
  geom_point(data=pooled, shape = 21, aes(color=habit), fill = 'black', size=3.5, 
             stroke =2.5, show.legend = FALSE) +
  ylim(c(-2.3, 2.3)) +
  coord_flip() +
  xlab("") + ylab("") +
  theme_minimal()+
  theme(text=element_text(family="sans", color = , size=11, face = 'bold'))
hfp + scale_color_manual(values=c("chocolate1", "Orchid3", "Seagreen4"))

####

key <- read.csv("~/Crassula PhD/Meta-analysis/pooledspecies.csv")

key$spandresp <- factor(key$spandresp, levels = c('Other sub: macroinvertebrates',
                                                  'Hydrilla: fish', 'Hydrilla: macroinvertebrates',
                                                  'Myriophyllum: macroinvertebrates', 'Myriophyllum: macrophytes',
                                                  'Phragmites: macrophytes', 'Typha: macrophytes'))

library(ggplot2)
keyf <- ggplot(data=key, aes(x=spandresp, y=g, ymin=ci_l, ymax=ci_h)) +
  geom_hline(yintercept=0, lty=2) +
  geom_errorbar(data=key, size=1, width=.2, aes(color = aliensp), show.legend = FALSE) +
  geom_point(data=key, shape = 21, aes(color=aliensp), fill = 'black', size=3, 
             stroke =2.7, show.legend = FALSE) +
  ylim(c(-3.1, 3.1)) +
  coord_flip() +
  xlab("") + ylab("") +
  theme_minimal()+
  theme(text=element_text(family="sans", color = , size=11, face = 'bold'))

keyf + scale_color_manual(values=c("#06a1a1", 'seagreen4', 'grey', "goldenrod2", "sienna3"))
